@@ -13,12 +13,12 @@ omegacor <- function(
 	if(length(unique(unilog$run))!=1)stop('need exactly one unique value of run')
 	unilog$value <- suppressWarnings(as.numeric(as.character(unilog$value)))
 	unilog <- data.frame(cast(unilog,parameter~moment))
-	indicies <- as.character(text2decimal(as.character(unilog$parameter)))
-	splits <- strsplit(indicies,'.',fixed=TRUE)
+	indices <- as.character(text2decimal(as.character(unilog$parameter)))
+	splits <- strsplit(indices,'.',fixed=TRUE)
 	all <- unlist(splits)
 	ord <- max(as.numeric(all))
 	nms <- names(half(diag(ord)))
-	nms <- paste(sep='','OMEGA',nms)
+	nms <- glue('OMEGA',nms)
 	val <- with(unilog, estimate[match(nms,parameter)])
 	cov <- as.matrix(as.halfmatrix(val))
 	cor <- cov2cor(cov)
